# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'RepositoryExternalConnectionArgs',
    'RepositoryUpstreamArgs',
]

@pulumi.input_type
class RepositoryExternalConnectionArgs:
    def __init__(__self__, *,
                 external_connection_name: Optional[pulumi.Input[str]] = None,
                 package_format: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] external_connection_name: The name of the external connection associated with a repository.
        :param pulumi.Input[str] package_format: The package format associated with a repository's external connection.
        :param pulumi.Input[str] status: The status of the external connection of a repository.
        """
        if external_connection_name is not None:
            pulumi.set(__self__, "external_connection_name", external_connection_name)
        if package_format is not None:
            pulumi.set(__self__, "package_format", package_format)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="externalConnectionName")
    def external_connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the external connection associated with a repository.
        """
        return pulumi.get(self, "external_connection_name")

    @external_connection_name.setter
    def external_connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_connection_name", value)

    @property
    @pulumi.getter(name="packageFormat")
    def package_format(self) -> Optional[pulumi.Input[str]]:
        """
        The package format associated with a repository's external connection.
        """
        return pulumi.get(self, "package_format")

    @package_format.setter
    def package_format(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_format", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the external connection of a repository.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class RepositoryUpstreamArgs:
    def __init__(__self__, *,
                 repository_name: pulumi.Input[str]):
        """
        :param pulumi.Input[str] repository_name: The name of an upstream repository.
        """
        pulumi.set(__self__, "repository_name", repository_name)

    @property
    @pulumi.getter(name="repositoryName")
    def repository_name(self) -> pulumi.Input[str]:
        """
        The name of an upstream repository.
        """
        return pulumi.get(self, "repository_name")

    @repository_name.setter
    def repository_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository_name", value)


